@@ -1,4 +1,4 @@
-/* $OpenBSD: bio.h,v 1.25 2014/07/13 10:27:22 beck Exp $ */
+/* $OpenBSD: bio.h,v 1.26 2014/07/13 14:13:27 beck Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -737,16 +737,18 @@ void BIO_copy_next_retry(BIO *b);
 
 int
 BIO_printf(BIO *bio, const char *format, ...)
-	__attribute__((__format__(__printf__, 2, 3)));
+	__attribute__((__format__(__printf__, 2, 3), __nonnull__(2)));
 int
 BIO_vprintf(BIO *bio, const char *format, va_list args)
-	__attribute__((__format__(__printf__, 2, 0)));
+	__attribute__((__format__(__printf__, 2, 0), __nonnull__(2)));
 int
 BIO_snprintf(char *buf, size_t n, const char *format, ...)
-	__attribute__((deprecated, __format__(__printf__, 3, 4)));
+	__attribute__((__deprecated__, __format__(__printf__, 3, 4),
+	    __nonnull__(3)));
 int
 BIO_vsnprintf(char *buf, size_t n, const char *format, va_list args)
-	__attribute__((deprecated, __format__(__printf__, 3, 0)));
+	__attribute__((__deprecated__, __format__(__printf__, 3, 0),
+	    __nonnull__(3)));
 
 /* BEGIN ERROR CODES */
 /* The following lines are auto generated by the script mkerr.pl. Any changes
