@@ -5,6 +5,10 @@
 
 #include <stdint.h>
 
+#ifdef __MINGW32__
+#include <_bsd_types.h>
+#endif
+
 #if !defined(HAVE_ATTRIBUTE__BOUNDED__) && !defined(__bounded__)
 # define __bounded__(x, y, z)
 #endif
